Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(831)

Unified Diff: net/ftp/ftp_util.h

Issue 6697021: FTP: use ICU to parse month abbreviations. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: removed unneeded header Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ftp/ftp_directory_listing_parser_vms.cc ('k') | net/ftp/ftp_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ftp/ftp_util.h
diff --git a/net/ftp/ftp_util.h b/net/ftp/ftp_util.h
index eb7e96309d0b04fd51d0fe61be7ac6afacea2cf3..de8d1705174f90d518b3cab92595f39b5956c879 100644
--- a/net/ftp/ftp_util.h
+++ b/net/ftp/ftp_util.h
@@ -27,9 +27,10 @@ class FtpUtil {
// Convert VMS path to Unix-style path.
static std::string VMSPathToUnix(const std::string& vms_path);
- // Convert three-letter month abbreviation (like Nov) to its number (in range
- // 1-12).
- static bool ThreeLetterMonthToNumber(const string16& text, int* number);
+ // Convert abbreviated month (like Nov) to its number (in range 1-12).
eroman 2011/03/16 00:46:45 nit: We should be using tense like "Converts" for
Paweł Hajdan Jr. 2011/03/16 20:17:28 Done.
+ // Note: in some locales abbreviations are more than three letters long,
+ // and this function also handles them correctly.
+ static bool AbbreviatedMonthToNumber(const string16& text, int* number);
// Convert a "ls -l" date listing to time. The listing comes in three columns.
// The first one contains month, the second one contains day of month.
« no previous file with comments | « net/ftp/ftp_directory_listing_parser_vms.cc ('k') | net/ftp/ftp_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698